@@ -261,7 +261,8 @@ crsEst <- function(xz,
               x=x,
               z=z,
               prune=prune,
-              prune.index=prune.index))
+              prune.index=prune.index,
+              P.hat=model$P.hat))
 
 }
 
@@ -850,7 +851,7 @@ predict.crs <- function(object,
 ## Basic print method.
 
 print.crs <- function(x,
-                         ...) {
+                      ...) {
 
   cat("Call:\n")
   print(x$call)
@@ -891,11 +892,17 @@ summary.crs <- function(object,
   cat(paste("\nBasis type: ",format(object$basis),sep=""))
   if(!object$kernel) cat(paste("\nPruning of final model: ",format(ifelse(object$prune,"TRUE","FALSE")),sep=""))
   cat(paste("\nTraining observations: ", format(object$nobs), sep=""))
-  cat(paste("\nRank of model frame: ", format(object$k), sep=""))  
-  cat(paste("\nResidual standard error: ", format(sqrt(sum(object$residuals^2)/object$df.residual),digits=4)," on ", format(object$df.residual)," degrees of freedom",sep=""))
+  cat(paste("\nRank of model frame: ", format(object$k), sep=""))
+  cat(paste("\nTrace of smoother matrix: ", format(round(sum(object$hatvalues))), sep=""))    
+  cat(paste("\n\nResidual standard error: ", format(sqrt(sum(object$residuals^2)/object$df.residual),digits=4)," on ", format(object$df.residual)," degrees of freedom",sep=""))
   adjusted.r.squared <- 1-(1-object$r.squared)*(length(object$fitted.values)-1)/object$df.residual
   cat(paste("\nMultiple R-squared: ", format(object$r.squared,digits=4),",   Adjusted R-squared: ",format(adjusted.r.squared,digits=4), sep=""))
-  cat(paste("\nCross-validation score: ", format(object$cv.score,digits=8), sep=""))  
+  df1 <- round(sum(object$hatvalues))-1
+  df2 <- (object$nobs-round(sum(object$hatvalues)))
+  F <- (df2/df1)*(sum((object$y-mean(object$y))^2)-sum(residuals(object)^2))/sum(residuals(object)^2)
+  cat(paste("\nF-statistic: ", format(F,digits=4), " on ", df1, " and ", df2, " DF, p-value: ", format(pf(F,df1=df1,df2=df2,lower.tail=FALSE),digits=4), sep=""))
+
+  cat(paste("\n\nCross-validation score: ", format(object$cv.score,digits=8), sep=""))  
   if(object$cv != "none") cat(paste("\nNumber of multistarts: ", format(object$nmulti), sep=""))
 
   if(sigtest&!object$kernel) {
@@ -1592,6 +1599,11 @@ plot.crs <- function(x,
 
 crs.sigtest <- function(object,...) {
 
+  ## This function for the asymptotic significance test can be
+  ## airlifted in trivially... trace of the smoother matrix etc. will
+  ## deliver correct F stat etc. Left for future 9/1/11 since we have
+  ## crssigtest function...
+
   if(object$kernel) stop(" sigtest is currently available only when kernel=FALSE")
 
   sg <- list()
