@@ -214,8 +214,8 @@ frscvNOMAD <- function(xz,
 
         set.seed(random.seed)
 
-        if(is.null(xdegree)) xdegree <- rep(1,num.x) # sample(degree.min:degree.max, num.x, replace=T)
-        if(is.null(xsegments)) xsegments <- sample(segments.min:segments.max, num.x, replace=T)
+        if(is.null(xdegree)) xdegree <- rep(1,num.x) ## sample(degree.min:degree.max, num.x, replace=T)
+        if(is.null(xsegments)) xsegments <- rep(1,num.x) ## sample(segments.min:segments.max, num.x, replace=T)
         if(is.null(xinclude)) xinclude <- sample(0:1, num.z, replace=T)
         
         if(complexity =="degree-knots") {
