@@ -237,7 +237,7 @@ krscvNOMAD <- function(xz,
         set.seed(random.seed)
 
         if(is.null(xdegree)) xdegree <- rep(1,num.x) ## sample(degree.min:degree.max, num.x, replace=T)
-        if(is.null(xsegments)) xsegments <- sample(segments.min:segments.max, num.x, replace=T)
+        if(is.null(xsegments)) xsegments <- rep(1,num.x) ## sample(segments.min:segments.max, num.x, replace=T)
         if(is.null(xlambda)) xlambda <- runif(num.z)
 
         if(complexity =="degree-knots") {
